@@ -2,7 +2,7 @@ package t::Helper;
 use Mojo::Base -base;
 use Test::More;
 
-my $USERNAME = $^O eq 'Win32' ? 'username' : scalar getpwuid $<;
+my $USERNAME = $ENV{USER} || 'postgresql';
 
 sub pg {
   my $class = shift;
@@ -12,7 +12,7 @@ sub pg {
 }
 
 sub import {
-  my $class = shift;
+  my $class  = shift;
   my $caller = caller;
 
   eval <<"HERE" or die $@;
